[libmarc-transform-perl] 01/01: Spelling fixes in the documentation

Robin Sheat eythian-guest at moszumanska.debian.org
Fri Nov 28 01:15:17 UTC 2014


This is an automated email from the git hooks/post-receive script.

eythian-guest pushed a commit to branch lintian-spelling-fix
in repository libmarc-transform-perl.

commit d2e465af31e6a806eb788ffa660cddb4b9f1c469
Author: Robin Sheat <robin at catalyst.net.nz>
Date:   Mon Oct 20 10:47:11 2014 +1300

    Spelling fixes in the documentation
---
 lib/MARC/Transform.pm | 40 ++++++++++++++++++++--------------------
 1 file changed, 20 insertions(+), 20 deletions(-)

diff --git a/lib/MARC/Transform.pm b/lib/MARC/Transform.pm
index e2db0b1..1a90b8f 100644
--- a/lib/MARC/Transform.pm
+++ b/lib/MARC/Transform.pm
@@ -1098,7 +1098,7 @@ For example, this means, that if we have more '501' fields in the record, if our
     #!/usr/bin/perl
     use MARC::Transform;
     my $record = MARC::Record->new();
-    $record->leader('optionnal leader');
+    $record->leader('optional leader');
     $record->insert_fields_ordered( MARC::Field->new('005', 'controlfield_content'));
     $record->insert_fields_ordered( MARC::Field->new('501', '', '', 'a' => 'foo', 'b' => 'bar') );
     print "\n--init record--\n". $record->as_formatted ."\n";
@@ -1663,7 +1663,7 @@ result (with C<< $record->as_formatted >>):
 
 =head4 $mth
 
-B<$mth> is the optional hashref add as third optional argument. It can be used in writing (into subs and global_subs) and reading. This allows to interact with the script that calls MARC::Transform.
+B<$mth> is the optional hashref add as third optional argument. It can be used in writing (into subs and global_subs) and reading. This allows interaction with the script that calls MARC::Transform.
 
 =over 4
 
@@ -1672,7 +1672,7 @@ B<$mth> is the optional hashref add as third optional argument. It can be used i
 =item * Example in a perl script :
 
     my $record = MARC::Record->new();
-    $record->leader('optionnal leader');
+    $record->leader('optional leader');
     print "--init record--\n". $record->as_formatted;
     my %mth;
     $mth{"inc"}=1;
@@ -1701,9 +1701,9 @@ B<$mth> is the optional hashref add as third optional argument. It can be used i
 result :
 
     --init record--
-    LDR optionnal leader
+    LDR optional leader
     --transformed record-- 3 : 
-    LDR optionnal leader
+    LDR optional leader
     500    _aa string
     600    _a3
 
@@ -1724,13 +1724,13 @@ B<$record> is the current MARC::Record object.
     #full rule:
     ---
     -
-     <method invokation syntax in the actions values, in sub-rule(s)>
+     <method invocation syntax in the actions values, in sub-rule(s)>
     -
      subs: >
         <one or more Perl subs>
     ---
     
     # method invokation syntax:
     \&<sub name>("<arguments>")
 
 =item * Example:
@@ -1798,7 +1798,7 @@ result (with C<< $record->as_formatted >>):
     global_subs: >
         <one or more Perl subs>
     
     # method invokation syntax:
     \&<sub name>("<arguments>")
 
 =item * Example:
@@ -1851,15 +1851,15 @@ If you want to use more than one LookUp Table in a rule, you must use a global_L
     #full rule:
     ---
     -
-     <LUT invokation syntax in the actions values, inside sub-rule(s)>
+     <LUT invocation syntax in the actions values, inside sub-rule(s)>
     -
      LUT :
        <starting value> : <final value>
        <starting value> : <final value>
-       _default_value_ : optionnal default value
+       _default_value_ : optional default value
     ---
     
     # LUT invokation syntax:
     \&LUT("<starting value>")
 
 =item * Example:
@@ -1907,7 +1907,7 @@ result (with C<< $record->as_formatted >> ):
       <starting value> : <final value>
       <starting value> : <final value>
     
-    # global_LUT invokation syntax:
+    # global_LUT invocation syntax:
     \&LUT("<starting value>","<LUT title>")
 
 =item * Example:
@@ -2100,7 +2100,7 @@ This yaml was called like this: C<< my %mth; $mth{"var"}="a string"; $record = M
 result (with C<< $record->as_formatted >> ) :
 
     --init record--
-    LDR optionnal leader
+    LDR optional leader
     005     controlfield_content
     008     controlfield_content8a
     008     controlfield_content8b
@@ -2124,7 +2124,7 @@ result (with C<< $record->as_formatted >> ) :
            _ctruc
     
     --transformed record--
-    LDR optionnalaleader
+    LDR optionalaleader
     006     UTF-8
     007     controlfield_content8b
     008     controlfield_content8a
@@ -2389,7 +2389,7 @@ Cela signifie, par exemple, que si nous avons plusieurs champs '501' dans la not
     #!/usr/bin/perl
     use MARC::Transform;
     my $record = MARC::Record->new();
-    $record->leader('optionnal leader');
+    $record->leader('optional leader');
     $record->insert_fields_ordered( MARC::Field->new('005', 'controlfield_content'));
     $record->insert_fields_ordered( MARC::Field->new('501', '', '', 'a' => 'foo', 'b' => 'bar') );
     print "\n--init record--\n". $record->as_formatted ."\n";
@@ -2963,7 +2963,7 @@ B<$mth> est l'éventuel hashref passé comme troisième argument. Il est utilisa
 =item * Exemple dans un script perl :
 
     my $record = MARC::Record->new();
-    $record->leader('optionnal leader');
+    $record->leader('optional leader');
     print "--init record--\n". $record->as_formatted;
     my %mth;
     $mth{"inc"}=1;
@@ -2992,9 +2992,9 @@ B<$mth> est l'éventuel hashref passé comme troisième argument. Il est utilisa
 résultat :
 
     --init record--
-    LDR optionnal leader
+    LDR optional leader
     --transformed record-- 3 : 
-    LDR optionnal leader
+    LDR optional leader
     500    _aa string
     600    _a3
 
@@ -3390,7 +3390,7 @@ Dans le YAML, ces caractères sont interprétés différemment. Pour les utilise
 résultat (avec C<< $record->as_formatted >> ) :
 
     --notice d'origine--
-    LDR optionnal leader
+    LDR optional leader
     005     controlfield_content
     008     controlfield_content8a
     008     controlfield_content8b
@@ -3414,7 +3414,7 @@ résultat (avec C<< $record->as_formatted >> ) :
            _ctruc
     
     --notice transformée--
-    LDR optionnalaleader
+    LDR optional leader
     006     UTF-8
     007     controlfield_content8b
     008     controlfield_content8a
@@ -1724,13 +1724,13 @@ B<$record> is the current MARC::Record object.
     ---
     
-    # method invokation syntax:
+    # method invocation syntax:
     \&<sub name>("<arguments>")
 
@@ -1798,7 +1798,7 @@ result (with C<< $record->as_formatted >>):
         <one or more Perl subs>
     
-    # method invokation syntax:
+    # method invocation syntax:
     \&<sub name>("<arguments>")
 
@@ -1851,15 +1851,15 @@ If you want to use more than one LookUp Table in a rule, you must use a global_L
     ---
     
-    # LUT invokation syntax:
+    # LUT invocation syntax:
     \&LUT("<starting value>")
 

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-perl/packages/libmarc-transform-perl.git



More information about the Pkg-perl-cvs-commits mailing list